@@ -14,7 +14,6 @@
 #include <coreplugin/icore.h>
 #include <coreplugin/idocument.h>
 
-#include <cppeditor/cppcodestylepreferences.h>
 #include <cppeditor/cppcodestylesettings.h>
 #include <cppeditor/cppcodestylesettingspage.h>
 #include <cppeditor/cppcodestylesnippets.h>
@@ -34,11 +33,10 @@
 #include <texteditor/texteditorsettings.h>
 
 #include <utils/guard.h>
+#include <utils/infolabel.h>
 #include <utils/layoutbuilder.h>
 #include <utils/qtcassert.h>
 #include <utils/utilsicons.h>
-#include <utils/infolabel.h>
-#include <utils/expected.h>
 
 #include <QComboBox>
 #include <QLabel>
@@ -66,51 +64,6 @@ static void invokeMethodForLanguageClientManager(const char *method, Args &&...a
     QMetaObject::invokeMethod(languageClientManager, method, args...);
 }
 
-class ClangFormatConfigWidget final : public TextEditor::CodeStyleEditorWidget
-{
-public:
-    ClangFormatConfigWidget(TextEditor::ICodeStylePreferences *codeStyle,
-                            Project *project,
-                            QWidget *parent);
-
-    ~ClangFormatConfigWidget()
-    {
-        auto doc = qobject_cast<TextEditor::TextDocument *>(m_editor->document());
-        invokeMethodForLanguageClientManager("documentClosed",
-                                             Q_ARG(Core::IDocument *, doc));
-    }
-
-    void apply() final;
-
-private:
-    bool eventFilter(QObject *object, QEvent *event) final;
-
-    FilePath globalPath();
-    FilePath projectPath();
-    void createStyleFileIfNeeded(bool isGlobal);
-
-    void initPreview(TextEditor::ICodeStylePreferences *codeStyle);
-    void initEditor();
-
-    void reopenClangFormatDocument(bool readOnly);
-
-    void updatePreview();
-    void slotCodeStyleChanged(TextEditor::ICodeStylePreferences *currentPreferences);
-
-    ProjectExplorer::Project *m_project = nullptr;
-    QWidget *m_editorWidget = nullptr;
-    QScrollArea *m_editorScrollArea = nullptr;
-    TextEditor::SnippetEditorWidget *m_preview = nullptr;
-    std::unique_ptr<Core::IEditor> m_editor;
-
-    std::unique_ptr<ClangFormatFile> m_config;
-
-    Guard m_ignoreChanges;
-    QLabel *m_clangVersion;
-    InfoLabel *m_clangFileIsCorrectText;
-    ClangFormatIndenter *m_indenter;
-};
-
 bool ClangFormatConfigWidget::eventFilter(QObject *object, QEvent *event)
 {
     if (event->type() == QEvent::Wheel && qobject_cast<QComboBox *>(object)) {
@@ -120,13 +73,8 @@ bool ClangFormatConfigWidget::eventFilter(QObject *object, QEvent *event)
     return QWidget::eventFilter(object, event);
 }
 
-static bool isReadOnlyCodeStyle(TextEditor::ICodeStylePreferences *style)
-{
-    return style->isReadOnly() || style->isTemporarilyReadOnly() || !style->isAdditionalTabVisible();
-}
-
 ClangFormatConfigWidget::ClangFormatConfigWidget(
-    TextEditor::ICodeStylePreferences *codeStyle, Project *project, QWidget *parent)
+    const Project *project, TextEditor::ICodeStylePreferences *codeStyle, QWidget *parent)
     : CodeStyleEditorWidget(parent)
 {
     m_project = project;
@@ -156,10 +104,16 @@ ClangFormatConfigWidget::ClangFormatConfigWidget(
 
     slotCodeStyleChanged(codeStyle->currentPreferences());
 
-    reopenClangFormatDocument(isReadOnlyCodeStyle(codeStyle));
+    reopenClangFormatDocument();
     updatePreview();
 }
 
+ClangFormatConfigWidget::~ClangFormatConfigWidget()
+{
+    auto doc = qobject_cast<TextEditor::TextDocument *>(m_editor->document());
+    invokeMethodForLanguageClientManager("documentClosed", Q_ARG(Core::IDocument *, doc));
+}
+
 void ClangFormatConfigWidget::slotCodeStyleChanged(TextEditor::ICodeStylePreferences *codeStyle)
 {
     if (!codeStyle)
@@ -167,10 +121,17 @@ void ClangFormatConfigWidget::slotCodeStyleChanged(TextEditor::ICodeStylePrefere
     m_config.reset(new ClangFormatFile(codeStyle));
     m_config->setIsReadOnly(codeStyle->isReadOnly());
 
-    reopenClangFormatDocument(isReadOnlyCodeStyle(codeStyle));
+    reopenClangFormatDocument();
+    updateReadOnlyState();
     updatePreview();
 }
 
+void ClangFormatConfigWidget::updateReadOnlyState()
+{
+    const bool isReadOnly = m_config->isReadOnly() || !m_useCustomSettings;
+    setDisabled(isReadOnly);
+}
+
 void ClangFormatConfigWidget::initEditor()
 {
     m_editorScrollArea = new QScrollArea();
@@ -179,8 +140,7 @@ void ClangFormatConfigWidget::initEditor()
     Core::IEditorFactory *factory = factories.takeFirst();
     m_editor.reset(factory->createEditor());
 
-    QString errorString;
-    m_editor->document()->open(&errorString, m_config->filePath(), m_config->filePath());
+    m_editor->document()->open(m_config->filePath(), m_config->filePath());
     m_editor->widget()->adjustSize();
 
     invokeMethodForLanguageClientManager("documentOpened",
@@ -202,7 +162,7 @@ void ClangFormatConfigWidget::initEditor()
 
     connect(m_editor->document(), &TextEditor::TextDocument::contentsChanged, this, [this] {
         clang::format::FormatStyle currentSettingsStyle{};
-        const Utils::expected_str<void> success
+        const Utils::Result<> success
             = parseConfigurationContent(m_editor->document()->contents().toStdString(),
                                         currentSettingsStyle);
 
@@ -219,7 +179,7 @@ void ClangFormatConfigWidget::initEditor()
 
     QShortcut *completionSC = new QShortcut(QKeySequence("Ctrl+Space"), this);
     connect(completionSC, &QShortcut::activated, this, [this] {
-        if (auto *editor = qobject_cast<TextEditor::BaseTextEditor *>(m_editor.get()))
+        if (auto editor = qobject_cast<TextEditor::BaseTextEditor *>(m_editor.get()))
             editor->editorWidget()->invokeAssist(TextEditor::Completion);
     });
 
@@ -308,20 +268,14 @@ void ClangFormatConfigWidget::updatePreview()
     m_preview->textDocument()->autoFormatOrIndent(cursor);
 }
 
-void ClangFormatConfigWidget::reopenClangFormatDocument(bool readOnly)
+void ClangFormatConfigWidget::reopenClangFormatDocument()
 {
     GuardLocker locker(m_ignoreChanges);
 
-    QString errorString;
-    if (m_editor->document()->open(&errorString, m_config->filePath(), m_config->filePath())
-        == Core::IDocument::OpenResult::Success) {
+    if (m_editor->document()->open(m_config->filePath(), m_config->filePath())) {
         invokeMethodForLanguageClientManager("documentOpened",
                                              Q_ARG(Core::IDocument *, m_editor->document()));
     }
-
-    auto textEditorWidget = qobject_cast<TextEditor::TextEditorWidget *>(m_editorWidget);
-    QTC_ASSERT(textEditorWidget, m_editorWidget->setEnabled(!readOnly); return;);
-    textEditorWidget->setReadOnly(readOnly);
 }
 
 void ClangFormatConfigWidget::apply()
@@ -332,12 +286,10 @@ void ClangFormatConfigWidget::apply()
     m_editor->document()->save(m_config->filePath());
 }
 
-TextEditor::CodeStyleEditorWidget *createClangFormatConfigWidget(
-    TextEditor::ICodeStylePreferences *codeStyle,
-    Project *project,
-    QWidget *parent)
+void ClangFormatConfigWidget::onUseCustomSettingsChanged(bool doUse)
 {
-    return new ClangFormatConfigWidget(codeStyle, project, parent);
+    m_useCustomSettings = doUse;
+    updateReadOnlyState();
 }
 
 } // namespace ClangFormat
