@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -37,21 +15,18 @@
 
 namespace ProjectExplorer {
 
-class JsonWizardFactory;
-class JsonWizardPageFactory;
-class JsonWizardGeneratorFactory;
 class ProjectExplorerPlugin;
 class ProjectExplorerPluginPrivate;
+namespace Internal { class ProjectExplorerTest; }
 
 // Documentation inside.
 class PROJECTEXPLORER_EXPORT JsonWizardFactory : public Core::IWizardFactory
 {
-    Q_OBJECT
+    Q_OBJECT // needed for qobject_cast
 
 public:
     // Add search paths for wizard.json files. All subdirs are going to be checked.
     static void addWizardPath(const Utils::FilePath &path);
-    static void clearWizardPaths();
 
     // actual interface of the wizard factory:
     class Generator {
@@ -71,20 +46,23 @@ public:
         int index = -1; // page index in the wizard
         Utils::Id typeId;
         QVariant enabled;
+        QVariant skipForSubprojects;
         QVariant data;
     };
 
-    static void registerPageFactory(JsonWizardPageFactory *factory);
-    static void registerGeneratorFactory(JsonWizardGeneratorFactory *factory);
-
     static QList<QVariant> objectOrList(const QVariant &data, QString *errorMessage);
 
     static QString localizedString(const QVariant &value);
 
     bool isAvailable(Utils::Id platformId) const override;
 
+    virtual std::pair<int, QStringList> screenSizeInfoFromPage(const QString &pageType) const;
+
+    // internal
+    static void setInstalledWizardsPath(const Utils::FilePath &path);
+
 private:
-    Utils::Wizard *runWizardImpl(const Utils::FilePath &path, QWidget *parent, Utils::Id platform,
+    Utils::Wizard *runWizardImpl(const Utils::FilePath &path, Utils::Id platform,
                                  const QVariantMap &variables, bool showWizard = true) override;
 
     // Create all wizards. As other plugins might register factories for derived
@@ -94,11 +72,11 @@ private:
                                                   const Utils::FilePath &baseDir,
                                                   QString *errorMessage);
     static Utils::FilePaths &searchPaths();
+    static void resetSearchPaths();
 
     static void setVerbose(int level);
     static int verbose();
 
-    static void destroyAllFactories();
     bool initialize(const QVariantMap &data, const Utils::FilePath &baseDir, QString *errorMessage);
 
     JsonWizardFactory::Page parsePage(const QVariant &value, QString *errorMessage);
@@ -120,25 +98,7 @@ private:
 
     friend class ProjectExplorerPlugin;
     friend class ProjectExplorerPluginPrivate;
+    friend class Internal::ProjectExplorerTest;
 };
 
-namespace Internal {
-
-class JsonWizardFactoryJsExtension : public QObject
-{
-    Q_OBJECT
-public:
-    JsonWizardFactoryJsExtension(Utils::Id platformId,
-                                 const QSet<Utils::Id> &availableFeatures,
-                                 const QSet<Utils::Id> &pluginFeatures);
-
-    Q_INVOKABLE QVariant value(const QString &name) const;
-
-private:
-    Utils::Id m_platformId;
-    QSet<Utils::Id> m_availableFeatures;
-    QSet<Utils::Id> m_pluginFeatures;
-};
-
-} // namespace Internal
 } // namespace ProjectExplorer
