@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "settings.h"
 
@@ -50,8 +28,11 @@
 #include <app/app_version.h>
 
 #include <iostream>
+#include <memory>
 
 #include <QCoreApplication>
+#include <QDir>
+#include <QLibraryInfo>
 #include <QStringList>
 
 void printHelp(const Operation *op)
@@ -81,10 +62,7 @@ void printHelp(const std::vector<std::unique_ptr<Operation>> &operations)
     std::cout << "    --sdkpath=PATH|-s PATH   Set the path to the SDK files" << std::endl << std::endl;
 
     std::cout << "Default sdkpath is \""
-              << qPrintable(QDir::cleanPath(
-                     Utils::FilePath::fromString(QCoreApplication::applicationDirPath())
-                         .pathAppended(DATA_PATH)
-                         .toUserOutput()))
+              << qPrintable(QDir::cleanPath(QCoreApplication::applicationDirPath() + '/' + DATA_PATH))
               << "\"" << std::endl
               << std::endl;
 
@@ -126,7 +104,7 @@ int parseArguments(const QStringList &args, Settings *s,
 
             // sdkpath
             if (current.startsWith(QLatin1String("--sdkpath="))) {
-                s->sdkPath = Utils::FilePath::fromString(current.mid(10));
+                s->sdkPath = current.mid(10);
                 continue;
             }
             if (current == QLatin1String("-s")) {
@@ -135,7 +113,7 @@ int parseArguments(const QStringList &args, Settings *s,
                     printHelp(operations);
                     return 1;
                 }
-                s->sdkPath = Utils::FilePath::fromString(next);
+                s->sdkPath = next;
                 ++i; // skip next;
                 continue;
             }
